@@ -55,7 +55,9 @@ public:
 
     QPlatformSystemTrayIcon *createPlatformSystemTrayIcon() const Q_DECL_OVERRIDE;
 
+#if QT_VERSION >= QT_VERSION_CHECK(5,7,0)
     QPlatformMenuBar *createPlatformMenuBar() const Q_DECL_OVERRIDE;
+#endif
 
 private:
     void loadSettings();
